==> custom_pages-v1.12.9.zip: custom_pages/messages/am/model.php <==
<?php

return [
    'Activate PHP based Pages and Snippets' => 'አገልግሎቱ የሚሰጡ መሰረታቸውን PHP ላይ ያደረጉ ገፃችና ቁንፅልመረጃዎች',
    'Content' => 'ይዘት',
    'Empty <br />Container' => 'ባዶ <br /> ማዕቀፍ',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'የማይሰራ ከሆነ፣ ቀድሞ የነበረው የpHP ገፅ አገልግሎት የሚሰጥ ይሆናል። ነገር ግን መፍጠር አይቻልም።',
    'Label' => 'ምልክት',
    'Open in new window' => 'በአዲስ መስኮት ውስጥ ክፈት',
    'PHP view path for custom space pages' => 'ለነባሪ የምህዳር ገፃች የሚሆን የPHP እይታ መንገድ',
    'PHP view path for custom space snippets' => 'ለነባሪ የምህዳር ቁንፅል መረጃ የሚሆን የphp እይታ መንገድ',
    'PHP view path for global custom pages' => 'ሉላዊ ለነባሪ ገፃች የሚሆን የphp እይታ መንገድ',
    'PHP view path for global custom snippets' => 'ለሉላዊ የነባሪ ቁንፅል መረጃ የሚሆን የphp እይታ መንገድ',
    'Placeholder name' => 'የቦታያዡ ስም',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'የአካሉ ስም ከ \'_\' ምልክት ውጪ ያለክፈተት እና ልዩ ምልክቶች ቢያንስ ሁለት የፅሁፍ ምልክቶችን መያዝ ይጠበቅበታል።',
    'The given element name is already in use for this template.' => 'የቀረበው አካል ስም በዚህ የድረገፅ አብነት ላይ ከዚህ ቀደም  አገልግሎት ላይ ውሏል።',
    'The given view file path does not exist.' => 'የቀረበው የፋይል መመልከቻ መንገድ አልተገኘም',
    'Url shortcut' => 'የurl አቋራጭመንገድ',
    'View' => 'ተመልከት',
    'Visibility' => 'የእይታ ሁኔታ',
    'page' => 'ገፅ',
    'snippet' => 'ቁንፅልመረጃ',
    'Abstract' => '',
    'Attach Files' => '',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/am/model.php <==
<?php

return [
    'Activate PHP based Pages and Snippets' => 'አገልግሎቱ የሚሰጡ መሰረታቸውን PHP ላይ ያደረጉ ገፃችና ቁንፅልመረጃዎች',
    'Content' => 'ይዘት',
    'Empty <br />Container' => 'ባዶ <br /> ማዕቀፍ',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'የማይሰራ ከሆነ፣ ቀድሞ የነበረው የpHP ገፅ አገልግሎት የሚሰጥ ይሆናል። ነገር ግን መፍጠር አይቻልም።',
    'Label' => 'ምልክት',
    'Open in new window' => 'በአዲስ መስኮት ውስጥ ክፈት',
    'PHP view path for custom space pages' => 'ለነባሪ የምህዳር ገፃች የሚሆን የPHP እይታ መንገድ',
    'PHP view path for custom space snippets' => 'ለነባሪ የምህዳር ቁንፅል መረጃ የሚሆን የphp እይታ መንገድ',
    'PHP view path for global custom pages' => 'ሉላዊ ለነባሪ ገፃች የሚሆን የphp እይታ መንገድ',
    'PHP view path for global custom snippets' => 'ለሉላዊ የነባሪ ቁንፅል መረጃ የሚሆን የphp እይታ መንገድ',
    'Placeholder name' => 'የቦታያዡ ስም',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'የአካሉ ስም ከ \'_\' ምልክት ውጪ ያለክፈተት እና ልዩ ምልክቶች ቢያንስ ሁለት የፅሁፍ ምልክቶችን መያዝ ይጠበቅበታል።',
    'The given element name is already in use for this template.' => 'የቀረበው አካል ስም በዚህ የድረገፅ አብነት ላይ ከዚህ ቀደም  አገልግሎት ላይ ውሏል።',
    'The given view file path does not exist.' => 'የቀረበው የፋይል መመልከቻ መንገድ አልተገኘም',
    'Url shortcut' => 'የurl አቋራጭመንገድ',
    'View' => 'ተመልከት',
    'Visibility' => 'የእይታ ሁኔታ',
    'page' => 'ገፅ',
    'snippet' => 'ቁንፅልመረጃ',
    'Abstract' => '',
    'Attach Files' => '',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
